// Copyright (C) 2020 VIRNECT CO., LTD.
// All rights reserved.

#pragma once
#include <VARAPI/TrackingFramework/Commons.hpp>

namespace VIRNECT {

namespace LOG {

/**
 * @brief Log level of API log messages
 */
enum class LogLevel
{
    LINFO = 1, ///< Log level info
    LWARN = 2, ///< Log level warning
    LERROR = 3 ///< Log level error
};

typedef void (*LoggingCallbackFunction)(const std::string&, LogLevel); ///< declaration of external callback function interface that can be invoked on a log event

/**
 * @brief Register a callback function that gets invoked when the framework logs an event.
 * @param function A LoggingCallbackFunction that accepts std::string and VIRNECT::LOG::LogLevel as parameters.
 */
VARAPI_EXPORT void registerLogCallbackFunction(LoggingCallbackFunction function);

/**
 * @brief Returns the latest log message
 * @return The most recent log message as string
 */
VARAPI_EXPORT const std::string getLastLogMessage();

/**
 * @brief Returns all log messages in ascending order (latest log is first)
 * @return A vector of log messages as string
 */
VARAPI_EXPORT const std::vector<std::string> getAllLogMessages();

} // namespace LOG

} // namespace VIRNECT
